"""
martian_api.

The martian python library allows developers to easily access the martian api.
"""

__version__ = "1.0.2"
__author__ = 'Shriyash Upadhyay'
__credits__ = 'Martian'

from .martian_api import *